@@ -75,6 +75,8 @@ bar for the same width.
     }
   }
 
+see eg/simle_use.pl
+
 Here is a simple example.  The process considers all the numbers between 0 and
 MAX, and updates the progress bar whenever it finds one.  Note that the
 progress bar update will be very erratic.  See below for a smoother example.
@@ -97,6 +99,8 @@ distribution set (it is not installed as part of the module).
     $progress->update($_)
   }
 
+See eg/smooth_bar.pl
+
 This example calls update for each value considered.  This will result in a
 much smoother progress update, but more program time is spent updating the bar
 than doing the "real" work.  See below to remedy this.  This example does
@@ -250,7 +254,7 @@ use constant DEBUG => 0;
 
 use vars qw($PACKAGE $VERSION);
 $PACKAGE = 'Term-ProgressBar';
-$VERSION = '2.08';
+$VERSION = '2.11';
 
 # ----------------------------------
 # CLASS CONSTRUCTION
@@ -775,10 +779,9 @@ sub update {
     if ( defined $ETA and $ratio > 0 ) {
       if ( $ETA eq 'linear' ) {
         if ( $ratio == 1 ) {
-#          $to_print .= '-- DONE --';
           my $taken = time - $self->start;
           my $ss    = $taken % 60;
-          my $mm    = ($taken - $ss) % 3600;
+          my $mm    = int(($taken % 3600) / 60);
           my $hh    = int($taken / 3600);
           if ( $hh > 99 ) {
             $to_print .= sprintf('D %2dh%02dm', $hh, $mm, $ss);
@@ -945,9 +948,9 @@ Significant contributions from Ed Avis, amongst others.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001, 2002, 2003,2004 Martyn J. Pearce.  This program is free
-software; you can redistribute it and/or modify it under the same terms as
-Perl itself.
+Copyright (c) 2001, 2002, 2003, 2004, 2005 Martyn J. Pearce.  This program is
+free software; you can redistribute it and/or modify it under the same terms
+as Perl itself.
 
 =head1	SEE ALSO
 
